# PyKP

<img align="left" width="110" height="110" src="https://raw.githubusercontent.com/HRSAndrabi/pykp/main/docs/source/_static/logo.svg" alt="pykp logo" style="padding-right: 15px">

[![PyPI Downloads](https://img.shields.io/pypi/dm/pykp.svg?label=Pypi%20downloads)](https://pypi.org/project/pykp/)
[![image](https://img.shields.io/pypi/v/pykp.svg)](https://pypi.python.org/pypi/pykp)
[![image](https://img.shields.io/pypi/l/pykp.svg)](https://github.com/astral-sh/pykp/blob/main/LICENSE)
[![image](https://img.shields.io/pypi/pyversions/pykp.svg)](https://pypi.python.org/pypi/pykp)

PyKP is an open-source Python library designed for efficiently solving and analysing knapsack problems. It includes tools for defining problem instances, solving them using various algorithms, and visualising and evaluating solutions.

- **Documentation:** [https://pykp.readthedocs.io](https://pykp.readthedocs.io)
- **Installation** [https://pykp.readthedocs.io/latest/installation/index.html](https://pykp.readthedocs.io/latest/installation/index.html)
- **Source code:** [https://github.com/pykp/pykp](https://github.com/HRSAndrabi/pykp)
- **Contributing:** [https://pykp.readthedocs.io/en/latest/contributing.html](https://pykp.readthedocs.io/latest/contributing/index.html)
- **Bug reports:** [https://github.com/HRSAndrabi/pykp/issues](https://github.com/HRSAndrabi/pykp/issues)

PyKP provides a Python interface for working with knapsack problems. For installation instructions, see [our install guide](https://pykp.readthedocs.io/latest/installation/index.html).

---

## Call for Contributions

Contributions via small improvements or fixes are always appreciated. If you are interested in contributing, have a look at [our contributing guide](https://pykp.readthedocs.io/latest/contributing/index.html).

Writing code isn’t the only way to contribute to PyKP. You can also:

- Review pull requests
- Develop tutorials, presentations, and other educational materials
- Maintain and improve the [documentation](https://pykp.readthedocs.io/latest/index.html)

If you are new to contributing to open source, [this guide](https://opensource.guide/how-to-contribute/) helps explain why, what, and how to get involved.
